@@ -8,25 +8,19 @@ from dev_shell.utils.colorful import bright_green
 from dev_shell.utils.subprocess_utils import verbose_check_call
 
 
-def run_linters(cwd=None):
+def run_linters(cwd=None, flynt_args=None):
     """
     Run code formatters and linter
     """
-    verbose_check_call(
-        'flake8',
-        cwd=cwd,
-        exit_on_error=True
-    )
-    verbose_check_call(
-        'isort', '--check-only', '.',
-        cwd=cwd,
-        exit_on_error=True
-    )
-    verbose_check_call(
-        'flynt', '--fail-on-change', '--line_length=119', '.',
-        cwd=cwd,
-        exit_on_error=True
-    )
+    if flynt_args is None:
+        flynt_args = ('--fail-on-change',)
+    verbose_check_call('flynt', *flynt_args, '.', cwd=cwd, exit_on_error=True)
+    verbose_check_call('darker', '--diff', '--check', cwd=cwd)
+
+
+def run_fix_code_style(cwd=None):
+    verbose_check_call('flynt', '.', cwd=cwd)
+    verbose_check_call('darker', cwd=cwd)
 
 
 @cmd2.with_default_category('dev-shell commands')
@@ -34,6 +28,9 @@ class DevShellCommandSet(DevShellBaseCommandSet):
     """
     This command set may be used in external project, too.
     """
+    # Overwrite flynt call args, because it has no support for config files.
+    # See: https://github.com/ikamensh/flynt/issues/111
+    flynt_args = None  # None == use defaults in run_linters()
 
     def do_pytest(self, statement: cmd2.Statement):
         """
@@ -64,24 +61,13 @@ class DevShellCommandSet(DevShellBaseCommandSet):
         """
         Linting: Check code style with flake8, isort and flynt
         """
-        run_linters(cwd=self.config.base_path)
+        run_linters(cwd=self.config.base_path, flynt_args=self.flynt_args)
 
     def do_fix_code_style(self, statement: cmd2.Statement):
         """
         Fix code style by running: flynt, autopep8 and isort
         """
-        verbose_check_call(
-            'flynt', '--line_length=119', '.',
-            cwd=self.config.base_path
-        )
-        verbose_check_call(
-            'autopep8', '--aggressive', '--aggressive', '--in-place', '--recursive', '.',
-            cwd=self.config.base_path
-        )
-        verbose_check_call(
-            'isort', '.',
-            cwd=self.config.base_path
-        )
+        run_fix_code_style(cwd=self.config.base_path)
 
     def do_list_venv_packages(self, statement: cmd2.Statement):
         """
